# CPMel

一个现代的maya python库



## 目录

- [快速开始](#快速开始)
- [功能介绍](#功能介绍)
- [版权说明](#版权说明)

### 快速开始

注意下方的python是你的Python, 正常情况下可以直接通过python调用, 而Maya的python一般是C:\Program Files\Autodesk\Maya2018\bin\mayapy.exe

#### 安装

```commandline
python -m pip install cpmel
```

### 版权说明

该项目签署了Apache-2.0 授权许可，详情请参阅 LICENSE